@@ -1,6 +1,7 @@
 package cmd
 
 import (
+	"context"
 	"fmt"
 	"strings"
 
@@ -70,6 +71,7 @@ func modInstallCmd() *cobra.Command {
 	cmdconfig.OnCmd(cmd).
 		AddBoolFlag(constants.ArgPrune, true, "Remove unused dependencies after installation is complete").
 		AddBoolFlag(constants.ArgDryRun, false, "Show which mods would be installed/updated/uninstalled without modifying them").
+		AddBoolFlag(constants.ArgForce, false, "Install mods even if plugin/cli version requirements are not met (cannot be used with --dry-run)").
 		AddBoolFlag(constants.ArgHelp, false, "Help for install", cmdconfig.FlagOptions.WithShortHand("h"))
 
 	return cmd
@@ -86,10 +88,29 @@ func runModInstallCmd(cmd *cobra.Command, args []string) {
 		}
 	}()
 
+	// try to load the workspace mod definition
+	// - if it does not exist, this will return a nil mod and a nil error
+	workspacePath := viper.GetString(constants.ArgModLocation)
+	workspaceMod, err := parse.LoadModfile(workspacePath)
+	error_helpers.FailOnErrorWithMessage(err, "failed to load mod definition")
+
+	// if no mod was loaded, create a default
+	if workspaceMod == nil {
+		workspaceMod, err = createWorkspaceMod(ctx, cmd, workspacePath)
+		if err != nil {
+			exitCode = constants.ExitCodeModInstallFailed
+			error_helpers.FailOnError(err)
+		}
+	}
+
 	// if any mod names were passed as args, convert into formed mod names
-	opts := newInstallOpts(cmd, args...)
-	installData, err := modinstaller.InstallWorkspaceDependencies(opts)
-	error_helpers.FailOnError(err)
+	opts := modinstaller.NewInstallOpts(workspaceMod, args...)
+	trimGitUrls(opts)
+	installData, err := modinstaller.InstallWorkspaceDependencies(ctx, opts)
+	if err != nil {
+		exitCode = constants.ExitCodeModInstallFailed
+		error_helpers.FailOnError(err)
+	}
 
 	fmt.Println(modinstaller.BuildInstallSummary(installData))
 }
@@ -122,7 +143,16 @@ func runModUninstallCmd(cmd *cobra.Command, args []string) {
 		}
 	}()
 
-	opts := newInstallOpts(cmd, args...)
+	// try to load the workspace mod definition
+	// - if it does not exist, this will return a nil mod and a nil error
+	workspaceMod, err := parse.LoadModfile(viper.GetString(constants.ArgModLocation))
+	error_helpers.FailOnErrorWithMessage(err, "failed to load mod definition")
+	if workspaceMod == nil {
+		fmt.Println("No mods installed.")
+		return
+	}
+	opts := modinstaller.NewInstallOpts(workspaceMod, args...)
+	trimGitUrls(opts)
 	installData, err := modinstaller.UninstallWorkspaceDependencies(ctx, opts)
 	error_helpers.FailOnError(err)
 
@@ -140,6 +170,7 @@ func modUpdateCmd() *cobra.Command {
 
 	cmdconfig.OnCmd(cmd).
 		AddBoolFlag(constants.ArgPrune, true, "Remove unused dependencies after update is complete").
+		AddBoolFlag(constants.ArgForce, false, "Update mods even if plugin/cli version requirements are not met (cannot be used with --dry-run)").
 		AddBoolFlag(constants.ArgDryRun, false, "Show which mods would be updated without modifying them").
 		AddBoolFlag(constants.ArgHelp, false, "Help for update", cmdconfig.FlagOptions.WithShortHand("h"))
 
@@ -157,9 +188,18 @@ func runModUpdateCmd(cmd *cobra.Command, args []string) {
 		}
 	}()
 
-	opts := newInstallOpts(cmd, args...)
+	// try to load the workspace mod definition
+	// - if it does not exist, this will return a nil mod and a nil error
+	workspaceMod, err := parse.LoadModfile(viper.GetString(constants.ArgModLocation))
+	error_helpers.FailOnErrorWithMessage(err, "failed to load mod definition")
+	if workspaceMod == nil {
+		fmt.Println("No mods installed.")
+		return
+	}
 
-	installData, err := modinstaller.InstallWorkspaceDependencies(opts)
+	opts := modinstaller.NewInstallOpts(workspaceMod, args...)
+	trimGitUrls(opts)
+	installData, err := modinstaller.InstallWorkspaceDependencies(ctx, opts)
 	error_helpers.FailOnError(err)
 
 	fmt.Println(modinstaller.BuildInstallSummary(installData))
@@ -188,7 +228,17 @@ func runModListCmd(cmd *cobra.Command, _ []string) {
 			exitCode = constants.ExitCodeUnknownErrorPanic
 		}
 	}()
-	opts := newInstallOpts(cmd)
+
+	// try to load the workspace mod definition
+	// - if it does not exist, this will return a nil mod and a nil error
+	workspaceMod, err := parse.LoadModfile(viper.GetString(constants.ArgModLocation))
+	error_helpers.FailOnErrorWithMessage(err, "failed to load mod definition")
+	if workspaceMod == nil {
+		fmt.Println("No mods installed.")
+		return
+	}
+
+	opts := modinstaller.NewInstallOpts(workspaceMod)
 	installer, err := modinstaller.NewModInstaller(opts)
 	error_helpers.FailOnError(err)
 
@@ -212,9 +262,10 @@ func modInitCmd() *cobra.Command {
 	return cmd
 }
 
-func runModInitCmd(cmd *cobra.Command, _ []string) {
-	ctx := cmd.Context()
+func runModInitCmd(cmd *cobra.Command, args []string) {
 	utils.LogTime("cmd.runModInitCmd")
+	ctx := cmd.Context()
+
 	defer func() {
 		utils.LogTime("cmd.runModInitCmd end")
 		if r := recover(); r != nil {
@@ -223,24 +274,42 @@ func runModInitCmd(cmd *cobra.Command, _ []string) {
 		}
 	}()
 	workspacePath := viper.GetString(constants.ArgModLocation)
-	if parse.ModfileExists(workspacePath) {
-		fmt.Println("Working folder already contains a mod definition file")
-		return
+	if _, err := createWorkspaceMod(ctx, cmd, workspacePath); err != nil {
+		exitCode = constants.ExitCodeModInitFailed
+		error_helpers.FailOnError(err)
 	}
-	mod := modconfig.CreateDefaultMod(workspacePath)
-	err := mod.Save()
-	error_helpers.FailOnError(err)
 	fmt.Printf("Created mod definition file '%s'\n", filepaths.ModFilePath(workspacePath))
 }
 
 // helpers
+func createWorkspaceMod(ctx context.Context, cmd *cobra.Command, workspacePath string) (*modconfig.Mod, error) {
+	if !modinstaller.ValidateModLocation(ctx, workspacePath) {
+		return nil, fmt.Errorf("mod %s cancelled", cmd.Name())
+	}
 
-func newInstallOpts(cmd *cobra.Command, args ...string) *modinstaller.InstallOpts {
-	opts := &modinstaller.InstallOpts{
-		WorkspacePath: viper.GetString(constants.ArgModLocation),
-		DryRun:        viper.GetBool(constants.ArgDryRun),
-		ModArgs:       args,
-		Command:       cmd.Name(),
+	if parse.ModfileExists(workspacePath) {
+		fmt.Println("Working folder already contains a mod definition file")
+		return nil, nil
+	}
+	mod := modconfig.CreateDefaultMod(workspacePath)
+	if err := mod.Save(); err != nil {
+		return nil, err
+	}
+
+	// load up the written mod file so that we get the updated
+	// block ranges
+	mod, err := parse.LoadModfile(workspacePath)
+	if err != nil {
+		return nil, err
+	}
+
+	return mod, nil
+}
+
+// Modifies(trims) the URL if contains http ot https in arguments
+func trimGitUrls(opts *modinstaller.InstallOpts) {
+	for i, url := range opts.ModArgs {
+		opts.ModArgs[i] = strings.TrimPrefix(url, "http://")
+		opts.ModArgs[i] = strings.TrimPrefix(url, "https://")
 	}
-	return opts
 }
