@@ -1,7 +1,7 @@
 package db_common
 
 import (
-	"github.com/jackc/pgconn"
+	"github.com/jackc/pgx/v5/pgconn"
 	"github.com/turbot/steampipe/pkg/utils"
 )
 
