@@ -6,7 +6,7 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/Masterminds/semver"
+	"github.com/Masterminds/semver/v3"
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
 	"github.com/hashicorp/hcl/v2/hclwrite"
@@ -27,36 +27,41 @@ type Mod struct {
 	// required to allow partial decoding
 	Remain hcl.Body `hcl:",remain" json:"-"`
 
-	// ModDependencyPath is the fully qualified mod name, which can be used to 'require'  the mod,
-	// e.g. github.com/turbot/steampipe-mod-azure-thrifty
-	// This is only set if the mod is installed as a dependency
-	ModDependencyPath string `cty:"mod_dependency_path"`
-
 	// attributes
 	Categories []string `cty:"categories" hcl:"categories,optional" column:"categories,jsonb"`
 	Color      *string  `cty:"color" hcl:"color" column:"color,text"`
 	Icon       *string  `cty:"icon" hcl:"icon" column:"icon,text"`
 
 	// blocks
-	Require       *Require
+	Require       *Require   `hcl:"require,block"`
 	LegacyRequire *Require   `hcl:"requires,block"`
 	OpenGraph     *OpenGraph `hcl:"opengraph,block" column:"open_graph,jsonb"`
 
-	VersionString string `cty:"version"`
-	Version       *semver.Version
+	// Depency attributes - set if this mod is loaded as a dependency
+
+	// the mod version
+	Version *semver.Version
+	// DependencyPath is the fully qualified mod name including version,
+	// which will by the map key in the workspace lock file
+	// NOTE: this is the relative path to th emod location from the depdemncy install dir (.steampipe/mods)
+	// e.g. github.com/turbot/steampipe-mod-azure-thrifty@v1.0.0
+	// (NOTE: pointer so it is nil in introspection tables if unpopulated)
+	DependencyPath *string `column:"dependency_path,text"`
+	// DependencyName return the name of the mod as a dependency, i.e. the mod dependency path, _without_ the version
+	// e.g. github.com/turbot/steampipe-mod-azure-thrifty
+	DependencyName string
 
 	// ModPath is the installation location of the mod
 	ModPath string
 
+	// convenient aggregation of all resources
+	ResourceMaps *ResourceMaps
+
 	// the filepath of the mod.sp file (will be empty for default mod)
 	modFilePath string
-	// convenient aggregation of all resources
-	// NOTE: this resource map object references the same set of resources
-	ResourceMaps *ResourceMaps
 }
 
 func NewMod(shortName, modPath string, defRange hcl.Range) *Mod {
-	require := NewRequire()
 	name := fmt.Sprintf("mod.%s", shortName)
 	mod := &Mod{
 		ModTreeItemImpl: ModTreeItemImpl{
@@ -69,30 +74,13 @@ func NewMod(shortName, modPath string, defRange hcl.Range) *Mod {
 			},
 		},
 		ModPath: modPath,
-		Require: require,
+		Require: NewRequire(),
 	}
 	mod.ResourceMaps = NewModResources(mod)
 
-	// try to derive mod version from the path
-	mod.setVersion()
-
 	return mod
 }
 
-func (m *Mod) setVersion() {
-	segments := strings.Split(m.ModPath, "@")
-	if len(segments) == 1 {
-		return
-	}
-	versionString := segments[len(segments)-1]
-	// try to set version, ignoring error
-	version, err := semver.NewVersion(versionString)
-	if err == nil {
-		m.Version = version
-		m.VersionString = fmt.Sprintf("%d.%d", version.Major(), version.Minor())
-	}
-}
-
 func (m *Mod) Equals(other *Mod) bool {
 	res := m.ShortName == other.ShortName &&
 		m.FullName == other.FullName &&
@@ -152,21 +140,6 @@ func (m *Mod) IsDefaultMod() bool {
 	return m.modFilePath == ""
 }
 
-func (m *Mod) NameWithVersion() string {
-	if m.VersionString == "" {
-		return m.ShortName
-	}
-	return fmt.Sprintf("%s@%s", m.ShortName, m.VersionString)
-}
-
-// GetModDependencyPath ModDependencyPath if it is set. If not it returns NameWithVersion()
-func (m *Mod) GetModDependencyPath() string {
-	if m.ModDependencyPath != "" {
-		return m.ModDependencyPath
-	}
-	return m.NameWithVersion()
-}
-
 // GetPaths implements ModTreeItem (override base functionality)
 func (m *Mod) GetPaths() []NodePath {
 	return []NodePath{{m.Name()}}
@@ -176,12 +149,7 @@ func (m *Mod) GetPaths() []NodePath {
 func (m *Mod) SetPaths() {}
 
 // OnDecoded implements HclResource
-func (m *Mod) OnDecoded(block *hcl.Block, resourceMapProvider ResourceMapsProvider) hcl.Diagnostics {
-	// if VersionString is set, set Version
-	if m.VersionString != "" && m.Version == nil {
-		m.Version, _ = semver.NewVersion(m.VersionString)
-	}
-
+func (m *Mod) OnDecoded(block *hcl.Block, _ ResourceMapsProvider) hcl.Diagnostics {
 	// handle legacy requires block
 	if m.LegacyRequire != nil && !m.LegacyRequire.Empty() {
 		// ensure that both 'require' and 'requires' were not set
@@ -201,16 +169,8 @@ func (m *Mod) OnDecoded(block *hcl.Block, resourceMapProvider ResourceMapsProvid
 	if m.Require == nil {
 		return nil
 	}
-	err := m.Require.initialise()
-	if err != nil {
-		return hcl.Diagnostics{&hcl.Diagnostic{
-			Severity: hcl.DiagError,
-			Summary:  err.Error(),
-			Subject:  &block.DefRange,
-		}}
-	}
-	return nil
 
+	return m.Require.initialise(block)
 }
 
 // AddReference implements ResourceWithMetadata (overridden from ResourceWithMetadataImpl)
@@ -303,10 +263,12 @@ func (m *Mod) Save() error {
 	}
 
 	// require
-	if require := m.Require; require != nil && !m.Require.Empty() {
+	if require := m.Require; require != nil && !require.Empty() {
 		requiresBody := modBody.AppendNewBlock("require", nil).Body()
-		if require.SteampipeVersionString != "" {
-			requiresBody.SetAttributeValue("steampipe", cty.StringVal(require.SteampipeVersionString))
+
+		if require.Steampipe != nil && require.Steampipe.MinVersionString != "" {
+			steampipeRequiresBody := requiresBody.AppendNewBlock("steampipe", nil).Body()
+			steampipeRequiresBody.SetAttributeValue("min_version", cty.StringVal(require.Steampipe.MinVersionString))
 		}
 		if len(require.Plugins) > 0 {
 			pluginValues := make([]cty.Value, len(require.Plugins))
@@ -377,14 +339,72 @@ func (m *Mod) SetFilePath(modFilePath string) {
 	m.modFilePath = modFilePath
 }
 
-func (m *Mod) ValidateSteampipeVersion() error {
+// ValidateRequirements validates that the current steampipe CLI and the installed plugins is compatible with the mod
+func (m *Mod) ValidateRequirements(pluginVersionMap map[string]*semver.Version) []error {
+	validationErrors := []error{}
+	if err := m.validateSteampipeVersion(); err != nil {
+		validationErrors = append(validationErrors, err)
+	}
+	pluginErr := m.validatePluginVersions(pluginVersionMap)
+	validationErrors = append(validationErrors, pluginErr...)
+	return validationErrors
+}
+
+func (m *Mod) validateSteampipeVersion() error {
 	if m.Require == nil {
 		return nil
 	}
-	return m.Require.ValidateSteampipeVersion(m.Name())
+	return m.Require.validateSteampipeVersion(m.Name())
+}
+
+func (m *Mod) validatePluginVersions(availablePlugins map[string]*semver.Version) []error {
+	if m.Require == nil {
+		return nil
+	}
+	return m.Require.validatePluginVersions(m.GetInstallCacheKey(), availablePlugins)
 }
 
 // CtyValue implements CtyValueProvider
 func (m *Mod) CtyValue() (cty.Value, error) {
 	return GetCtyValue(m)
 }
+
+// GetInstallCacheKey returns the key used to find this mod in a workspace lock InstallCache
+func (m *Mod) GetInstallCacheKey() string {
+	// if the ModDependencyPath is set, this is a dependency mod - use that
+	if m.DependencyPath != nil {
+		return *m.DependencyPath
+	}
+	// otherwise use the short name
+	return m.ShortName
+}
+
+// SetDependencyConfig sets DependencyPath, DependencyName and Version
+func (m *Mod) SetDependencyConfig(dependencyPath string) error {
+	// parse the dependency path to get the dependency name and version
+	dependencyName, version, err := ParseModDependencyPath(dependencyPath)
+	if err != nil {
+		return err
+	}
+	m.DependencyPath = &dependencyPath
+	m.DependencyName = dependencyName
+	m.Version = version
+	return nil
+}
+
+// RequireHasUnresolvedArgs returns whether the mod has any mod requirements which have unresolved args
+// (this could be because the arg refers to a variable, meanin gwe need an additional parse phase
+// to resolve the arg values)
+func (m *Mod) RequireHasUnresolvedArgs() bool {
+	if m.Require == nil {
+		return false
+	}
+	for _, m := range m.Require.Mods {
+		for _, a := range m.Args {
+			if !a.IsKnown() {
+				return true
+			}
+		}
+	}
+	return false
+}
